Crate urbit_chatbot_framework[−][src]
Structs
| AuthoredMessage | A |
| Chatbot | This struct represents a chatbot that is connected to a given |
Type Definitions
| Message | A struct that represents a message that is to be sent to an Urbit chat.
|
| AuthoredMessage | A |
| Chatbot | This struct represents a chatbot that is connected to a given |
| Message | A struct that represents a message that is to be sent to an Urbit chat.
|